@@ -3,7 +3,7 @@
 from collections import OrderedDict
 from torch import nn
 import torch
-
+import numpy as np
 
 class ContextualInferenceNetwork(nn.Module):
 
@@ -82,8 +82,6 @@ class ContextualInferenceNetwork(nn.Module):
         return mu, log_sigma
 
 
-
-
 class CombinedInferenceNetwork(nn.Module):
 
     """Inference Network."""
@@ -102,7 +100,7 @@ class CombinedInferenceNetwork(nn.Module):
         """
         super(CombinedInferenceNetwork, self).__init__()
         assert isinstance(input_size, int), "input_size must by type int."
-        assert isinstance(output_size, int), "output_size must be type int."
+        assert (isinstance(output_size, int) or isinstance(output_size, np.int64)), "output_size must be type int."
         assert isinstance(hidden_sizes, tuple), \
             "hidden_sizes must be type tuple."
         assert activation in ['softplus', 'relu', 'sigmoid', 'tanh', 'leakyrelu',
